/* Truss Generator include file for Persistence of Vision 3.x
	created by Theran Cochran on January 3, 1998

	Based on various include files by Chris Colefax, especially coil.inc, from
	which I copied both the style and code for positioning of the final object.

	Usage: #declare the truss_point1 and truss_point2 vectors and any other options,
	#include this file within an object { } statement and add any textures, transformations,
	etc. Basically, you can treat it as you would any other object.

	Example:

	  #declare truss_point1 = y*-5
	  #declare truss_point2 = y*5
	  object {
	     #include "truss.inc"
	     texture { fooTexture }
	  }


	Options:
	--Option--------------Default-
	 truss_sides         4
	 truss_type          1
	 truss_sections      3
	 truss_radius        1
	 truss_rings         true
	 truss_thickness     .05
	 truss_pyramid_ends  false
	 truss_mirror        true
	 truss_ball_joints   false
	 truss_ball_radius   .1
	 truss_rotate        0
	 truss_flip          false
	 truss_no_beams      false

	Please pardon my lack of documentation.
*/

#ifndef(truss_point1) #declare truss_point1 = <0, 0, 0> #end
#ifndef(truss_point2) #declare truss_point2 = <0, 1, 0> #end
#ifndef(truss_sides) #declare truss_sides = 4 #end
#ifndef(truss_angle) #declare truss_angle = 360 #end
#ifndef(truss_type) #declare truss_type = 1 #end
#ifndef(truss_sections) #declare truss_sections = 3 #end
#ifndef(truss_radius) #declare truss_radius = 1 #end
#ifndef(truss_rings) #declare truss_rings = 1 #end
#ifndef(truss_thickness) #declare truss_thickness = .05 #end
#ifndef(truss_pyramid_ends) #declare truss_pyramid_ends = false #end
#ifndef(truss_mirror) #declare truss_mirror = true #end
#ifndef(truss_ball_joints) #declare truss_ball_joints = false #end
#ifndef(truss_ball_radius) #declare truss_ball_radius = .1 #end
#ifndef(truss_rotate) #declare truss_rotate = 0 #end
#ifndef(truss_flip) #declare truss_flip = false #end
#ifndef(truss_no_beams) #declare truss_no_beams = false #end

#if(truss_pyramid_ends) #declare _TG_pyra = 1 #else #declare _TG_pyra = 0 #end

#declare _TG_axis = (truss_point2 - truss_point1) * <1, 1, 1>
#declare _TG_length = vlength(_TG_axis)
#declare _TG_slength = _TG_length / truss_sections
#declare _TG_srotate = y*truss_angle/truss_sides
#declare _TG_rotx = degrees(atan2(vlength(_TG_axis * <1, 0, 1>), _TG_axis.y))
#declare _TG_roty = degrees(atan2(_TG_axis.x, _TG_axis.z))



/***********rings************/
#if(truss_rings|truss_ball_joints)
	#declare _TG_ring = union {
		#declare _TG_foo = 0
		#while(_TG_foo < truss_sides)
			#if(truss_rings) cylinder { x*truss_radius, vrotate(x*truss_radius, _TG_srotate), truss_thickness rotate _TG_srotate*_TG_foo } #end
			#if(truss_ball_joints) sphere { x*truss_radius, truss_ball_radius rotate _TG_srotate*_TG_foo } #end
			#declare _TG_foo = _TG_foo + 1
		#end
	}
#end

#switch(truss_type)
/***********truss type 1************/
	#case(1)
		#declare _TG_sect = union {
			#declare _TG_foo = 0
			#while(_TG_foo < truss_sides)
				cylinder { x*truss_radius, vrotate(y*_TG_slength+x*truss_radius, _TG_srotate), truss_thickness rotate _TG_srotate*_TG_foo }
				#declare _TG_foo = _TG_foo + 1
			#end
		}
	#break

/***********truss type 2************/
	#case(2)
		#declare _TG_sect = union {
			#declare _TG_foo = 0
			#while(_TG_foo < truss_sides)
				#if(mod(_TG_foo, 2)) cylinder { x*truss_radius, vrotate(y*_TG_slength+x*truss_radius, _TG_srotate), truss_thickness rotate _TG_srotate*_TG_foo }
				#else cylinder { vrotate(x*truss_radius, _TG_srotate), y*_TG_slength+x*truss_radius, truss_thickness rotate _TG_srotate*_TG_foo } #end
				#declare _TG_foo = _TG_foo + 1
			#end
		}
	#break

/***********truss type 3************/
	#case(3)
		#declare _TG_sect = union {
			#declare _TG_foo = 0
			#while(_TG_foo < truss_sides)
				cylinder { x*truss_radius, vrotate(y*_TG_slength+x*truss_radius, _TG_srotate), truss_thickness rotate _TG_srotate*_TG_foo }
				cylinder { vrotate(x*truss_radius, _TG_srotate), y*_TG_slength+x*truss_radius, truss_thickness rotate _TG_srotate*_TG_foo }
				#declare _TG_foo = _TG_foo + 1
			#end
		}
	#break

/***********truss type 4************/
	#case(4)
		#declare _TG_sect = union {
			#declare _TG_a = (.5*(vrotate(x*truss_radius, _TG_srotate)-x*truss_radius)+x*truss_radius)+y*_TG_slength
			#declare _TG_foo = 0
			#while(_TG_foo < truss_sides)
					cylinder { x*truss_radius, _TG_a, truss_thickness rotate _TG_srotate*_TG_foo }
					cylinder { vrotate(x*truss_radius, _TG_srotate), _TG_a, truss_thickness rotate _TG_srotate*_TG_foo }
				#declare _TG_foo = _TG_foo + 1
			#end
		}
	#break

/***********truss type 5************/
	#case(5)
		#declare _TG_sect = union {
			#declare _TG_foo = 0
			#while(_TG_foo < truss_sides)
				cylinder { x*truss_radius+y*_TG_slength, 0, truss_thickness
					rotate _TG_srotate*_TG_foo
				}
				#declare _TG_foo = _TG_foo + 1
			#end
		}
	#break

/***********if all else fails************/
	#else
		#declare _TG_sect = union {}
		#warning "Warning: truss.inc Invalid truss type"
	#break
#end

union {
/***********the truss sections************/
	#declare _TG_foo = 0 + _TG_pyra
	#while(_TG_foo < truss_sections - _TG_pyra)
		object { _TG_sect
			#if(truss_flip) scale <1, -1, 1> translate y*_TG_slength #end
			#if(mod(_TG_foo, 2)&truss_mirror) scale <1, -1, 1> translate y*_TG_slength #end
			translate y*_TG_foo*_TG_slength
		}
		#if(truss_rings|truss_ball_joints) object { _TG_ring translate y*_TG_foo*_TG_slength } #end
		#declare _TG_foo = _TG_foo + 1
	#end
	#if(truss_rings|truss_ball_joints) object { _TG_ring translate y*(_TG_length-_TG_pyra*_TG_slength) } #end
	#declare _TG_foo = 0

/***********outer beams************/
	#if(!truss_no_beams)
		#while(_TG_foo < truss_sides)
			cylinder { x*truss_radius+_TG_pyra*y*_TG_slength, y*(_TG_length-_TG_pyra*_TG_slength)+x*truss_radius, truss_thickness rotate _TG_srotate*_TG_foo }
			#declare _TG_foo = _TG_foo + 1
		#end
		#if(mod(truss_angle, 360))
			cylinder { x*truss_radius+_TG_pyra*y*_TG_slength, y*(_TG_length-_TG_pyra*_TG_slength)+x*truss_radius, truss_thickness rotate y*truss_angle }
		#end
	#end


/***********pyramid ends************/
	#if(truss_pyramid_ends)
		#declare _TG_foo = 0
		#while(_TG_foo < truss_sides)
			#if(truss_ball_joints) sphere { y*_TG_length, truss_ball_radius }	sphere { 0, truss_ball_radius } #end
			cylinder { 0, y*_TG_slength+x*truss_radius, truss_thickness rotate _TG_srotate*_TG_foo }
			cylinder { y*_TG_length, y*(_TG_length-_TG_slength)+x*truss_radius, truss_thickness rotate _TG_srotate*_TG_foo }
			#declare _TG_foo = _TG_foo + 1
		#end
	#end

	rotate y*truss_rotate
	rotate <_TG_rotx, _TG_roty, 0>
	translate truss_point1
}
