/* Truss Generator include file for Persistence of Vision 3.x
	created by Theran Cochran on January 3, 1998
	
	Conic Section

	Example:

	  #declare truss_point1 = -y*2
	  #declare truss_point2 = y*2
	  #declare truss_radius1 = 1
	  #declare truss_radius2 = 2
	  object {
	     #include "truss_c.inc"
	     texture { fooTexture }
	  }


	Options:
	--Option--------------Default-
	 truss_type          1
	 truss_sections      3
	 truss_rings         true
	 truss_thickness     .05
	 truss_mirror        true
	 truss_ball_joints   false
	 truss_ball_radius   .1
	 truss_flip          false

	Please pardon my lack of documentation.
*/

#ifndef(truss_point1) #declare truss_point1 = <0, 1, 0> #end
#ifndef(truss_point2) #declare truss_point2 = <0, 0, 0> #end
#ifndef(truss_sides) #declare truss_sides = 4 #end
#ifndef(truss_radius1) #declare truss_radius1 = 1 #end
#ifndef(truss_radius2) #declare truss_radius2 = 2 #end
#ifndef(truss_thickness) #declare truss_thickness = .05 #end
#ifndef(truss_rotate) #declare truss_rotate = 0 #end
#ifndef(truss_flip) #declare truss_flip = false #end
#ifndef(truss_no_beams) #declare truss_no_beams = false #end
#ifndef(truss_angle) #declare truss_angle = 360 #end

#declare _TG_axis = (truss_point1-truss_point2) * <1, 1, 1>
#declare _TG_length = vlength(_TG_axis)
#declare _TG_srotate = y*truss_angle/truss_sides
#declare _TG_rotx = degrees(atan2(vlength(_TG_axis * <1, 0, 1>), _TG_axis.y))
#declare _TG_roty = degrees(atan2(_TG_axis.x, _TG_axis.z))


#declare truss_pointa1 = x*truss_radius1+y*_TG_length
#declare truss_pointa2 = x*truss_radius2
#declare truss_pointb1 = vrotate(truss_pointa1, _TG_srotate)
#declare truss_pointb2 = vrotate(truss_pointa2, _TG_srotate)

#declare _TG_tc = true
#declare _TG_side = object { #include "truss_s.inc" }
#declare _TG_tc = false

union {
	#declare _TG_foo = 0
	#while(_TG_foo < truss_sides)
		#if(truss_type!=2)
			object { _TG_side rotate _TG_srotate*_TG_foo }
		#else
			#if(mod(_TG_foo, 2))
				object { _TG_side scale <1, 1, -1> rotate _TG_srotate*(_TG_foo+1) }
			#else
				object { _TG_side rotate _TG_srotate*_TG_foo }
			#end
		#end

		#if(!truss_no_beams)
			cylinder { truss_pointa1, truss_pointa2, truss_thickness rotate _TG_srotate*_TG_foo }
		#end
		#declare _TG_foo = _TG_foo + 1
	#end
	#if(!truss_no_beams&mod(truss_angle, 360))
		cylinder { truss_pointa1, truss_pointa2, truss_thickness rotate y*truss_angle }
	#end

	rotate y*truss_rotate
	rotate <_TG_rotx, _TG_roty, 0>
	translate truss_point2
}
