/* Truss Generator include file for Persistence of Vision 3.x
	created by Theran Cochran on January 3, 1998

	Single Side

	Example:

	  #declare truss_pointa1 = y*-5
	  #declare truss_pointa2 = y*5
	  #declare truss_pointb1 = x+y*-5
	  #declare truss_pointb2 = x+y*5
	  object {
	     #include "truss_s.inc"
	     texture { fooTexture }
	  }


	Options:
	--Option--------------Default-
	 truss_type          1
	 truss_sections      3
	 truss_rings         true
	 truss_thickness     .05
	 truss_mirror        true
	 truss_ball_joints   false
	 truss_ball_radius   .1
	 truss_flip          false

	Please pardon my lack of documentation.
*/

#ifndef(truss_pointa1) #declare truss_pointa1 = <-.5, 0, 0> #end
#ifndef(truss_pointa2) #declare truss_pointa2 = <-.5, 1, 0> #end
#ifndef(truss_pointb1) #declare truss_pointb1 = <.5, 0, 0> #end
#ifndef(truss_pointb2) #declare truss_pointb2 = <.5, 1, 0> #end
#ifndef(truss_type) #declare truss_type = 1 #end
#ifndef(truss_sections) #declare truss_sections = 3 #end
#ifndef(truss_rings) #declare truss_rings = 1 #end
#ifndef(truss_thickness) #declare truss_thickness = .05 #end
#ifndef(truss_mirror) #declare truss_mirror = true #end
#ifndef(truss_ball_joints) #declare truss_ball_joints = false #end
#ifndef(truss_ball_radius) #declare truss_ball_radius = .1 #end
#ifndef(truss_flip) #declare truss_flip = false #end


#if(truss_flip)

#declare _TG_incrA = (truss_pointa1 - truss_pointa2)/truss_sections
#declare _TG_incrB = (truss_pointb1 - truss_pointb2)/truss_sections
#declare _TG_curA = truss_pointa2
#declare _TG_curB = truss_pointb2

#else

#declare _TG_incrA = (truss_pointa2 - truss_pointa1)/truss_sections
#declare _TG_incrB = (truss_pointb2 - truss_pointb1)/truss_sections
#declare _TG_curA = truss_pointa1
#declare _TG_curB = truss_pointb1

#end

union {
	#declare _TG_foo = 0
		#if(truss_rings)
			cylinder { _TG_curA, _TG_curB, truss_thickness }
		#end
		#if(truss_ball_joints)
			sphere { _TG_curA, truss_ball_radius }
			sphere { _TG_curB, truss_ball_radius }
		#end

	#while(_TG_foo < truss_sections)
		#declare _TG_lstA=_TG_curA
		#declare _TG_curA=_TG_lstA + _TG_incrA
		#declare _TG_lstB=_TG_curB
		#declare _TG_curB=_TG_lstB + _TG_incrB

		#if(truss_rings)
			cylinder { _TG_curA, _TG_curB, truss_thickness }
		#end
		#if(truss_ball_joints)
			sphere { _TG_curA, truss_ball_radius }
			sphere { _TG_curB, truss_ball_radius }
		#end


		#switch(truss_type)

			/***********truss type 1 or 2************/
			#range(1, 2)
				#if(truss_mirror&mod(_TG_foo, 2))
					cylinder { _TG_curB, _TG_lstA, truss_thickness }
				#else
					cylinder { _TG_curA, _TG_lstB, truss_thickness }
				#end
			#break

			#case(2) #if(!_TG_tc) #warning "Warning: Truss type 2 is same as 1 in trussside.inc" #end #break

			/***********truss type 3************/
			#case(3)
				cylinder { _TG_curA, _TG_lstB, truss_thickness }
				cylinder { _TG_curB, _TG_lstA, truss_thickness }
			#break

			/***********truss type 4************/
			#case(4)
				#if(truss_mirror&mod(_TG_foo, 2))
					#declare _TG_a = (_TG_lstA+_TG_lstB)*.5
					cylinder { _TG_curA, _TG_a, truss_thickness }
					cylinder { _TG_curB, _TG_a, truss_thickness }
				#else
					#declare _TG_a = (_TG_curA+_TG_curB)*.5
					cylinder { _TG_lstA, _TG_a, truss_thickness }
					cylinder { _TG_lstB, _TG_a, truss_thickness }
				#end
				#if(truss_ball_joints)
					sphere { _TG_a, truss_ball_radius }
				#end
			#break

			/***********if all else fails************/
			#else
				#warning "Warning: trussside.inc Invalid truss type"
			#break
		#end
		#declare _TG_foo = _TG_foo + 1
	#end
}
